@@ -17,9 +17,12 @@
 
 package org.apache.doris.flink.serialization;
 
+import org.apache.flink.util.Preconditions;
+
 import org.apache.arrow.memory.RootAllocator;
 import org.apache.arrow.vector.BigIntVector;
 import org.apache.arrow.vector.BitVector;
+import org.apache.arrow.vector.DateDayVector;
 import org.apache.arrow.vector.DecimalVector;
 import org.apache.arrow.vector.FieldVector;
 import org.apache.arrow.vector.FixedSizeBinaryVector;
@@ -27,6 +30,7 @@ import org.apache.arrow.vector.Float4Vector;
 import org.apache.arrow.vector.Float8Vector;
 import org.apache.arrow.vector.IntVector;
 import org.apache.arrow.vector.SmallIntVector;
+import org.apache.arrow.vector.TimeStampMicroVector;
 import org.apache.arrow.vector.TinyIntVector;
 import org.apache.arrow.vector.VarBinaryVector;
 import org.apache.arrow.vector.VarCharVector;
@@ -41,7 +45,6 @@ import org.apache.doris.flink.exception.DorisException;
 import org.apache.doris.flink.exception.DorisRuntimeException;
 import org.apache.doris.flink.rest.models.Schema;
 import org.apache.doris.sdk.thrift.TScanBatchResult;
-import org.apache.flink.util.Preconditions;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -49,8 +52,10 @@ import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.math.BigDecimal;
 import java.math.BigInteger;
+import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
+import java.time.ZoneId;
 import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -58,9 +63,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.NoSuchElementException;
 
-/**
- * row batch data container.
- */
+/** row batch data container. */
 public class RowBatch {
     private static Logger logger = LoggerFactory.getLogger(RowBatch.class);
 
@@ -90,10 +93,12 @@ public class RowBatch {
     private List<FieldVector> fieldVectors;
     private RootAllocator rootAllocator;
     private final Schema schema;
-    private final String DATETIME_PATTERN = "yyyy-MM-dd HH:mm:ss";
-    private final String DATETIMEV2_PATTERN = "yyyy-MM-dd HH:mm:ss.SSSSSS";
-    private final DateTimeFormatter dateTimeFormatter = DateTimeFormatter.ofPattern(DATETIME_PATTERN);
-    private final DateTimeFormatter dateTimeV2Formatter = DateTimeFormatter.ofPattern(DATETIMEV2_PATTERN);
+    private static final String DATETIME_PATTERN = "yyyy-MM-dd HH:mm:ss";
+    private static final String DATETIMEV2_PATTERN = "yyyy-MM-dd HH:mm:ss.SSSSSS";
+    private final DateTimeFormatter dateTimeFormatter =
+            DateTimeFormatter.ofPattern(DATETIME_PATTERN);
+    private final DateTimeFormatter dateTimeV2Formatter =
+            DateTimeFormatter.ofPattern(DATETIMEV2_PATTERN);
     private final DateTimeFormatter dateFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
 
     public List<Row> getRowBatch() {
@@ -103,10 +108,9 @@ public class RowBatch {
     public RowBatch(TScanBatchResult nextResult, Schema schema) {
         this.schema = schema;
         this.rootAllocator = new RootAllocator(Integer.MAX_VALUE);
-        this.arrowStreamReader = new ArrowStreamReader(
-                new ByteArrayInputStream(nextResult.getRows()),
-                rootAllocator
-        );
+        this.arrowStreamReader =
+                new ArrowStreamReader(
+                        new ByteArrayInputStream(nextResult.getRows()), rootAllocator);
         this.offsetInRowBatch = 0;
     }
 
@@ -115,10 +119,13 @@ public class RowBatch {
             this.root = arrowStreamReader.getVectorSchemaRoot();
             while (arrowStreamReader.loadNextBatch()) {
                 fieldVectors = root.getFieldVectors();
-                if (fieldVectors.size() != schema.size()) {
-                    logger.error("Schema size '{}' is not equal to arrow field size '{}'.",
-                            fieldVectors.size(), schema.size());
-                    throw new DorisException("Load Doris data failed, schema size of fetch data is wrong.");
+                if (fieldVectors.size() > schema.size()) {
+                    logger.error(
+                            "Data schema size '{}' should not be bigger than arrow field size '{}'",
+                            schema.size(),
+                            fieldVectors.size());
+                    throw new DorisException(
+                            "Load Doris data failed, schema size of fetch data is wrong.");
                 }
                 if (fieldVectors.size() == 0 || root.getRowCount() == 0) {
                     logger.debug("One batch in arrow has no data.");
@@ -150,8 +157,8 @@ public class RowBatch {
 
     private void addValueToRow(int rowIndex, Object obj) {
         if (rowIndex > rowCountInOneBatch) {
-            String errMsg = "Get row offset: " + rowIndex + " larger than row size: " +
-                    rowCountInOneBatch;
+            String errMsg =
+                    "Get row offset: " + rowIndex + " larger than row size: " + rowCountInOneBatch;
             logger.error(errMsg);
             throw new NoSuchElementException(errMsg);
         }
@@ -166,7 +173,8 @@ public class RowBatch {
                 final String currentType = schema.get(col).getType();
                 for (int rowIndex = 0; rowIndex < rowCountInOneBatch; rowIndex++) {
                     boolean passed = doConvert(col, rowIndex, minorType, currentType, fieldVector);
-                    Preconditions.checkArgument(passed, typeMismatchMessage(currentType, minorType));
+                    Preconditions.checkArgument(
+                            passed, typeMismatchMessage(currentType, minorType));
                 }
             }
         } catch (Exception e) {
@@ -175,62 +183,81 @@ public class RowBatch {
         }
     }
 
-    private boolean doConvert(int col,
-                              int rowIndex,
-                              Types.MinorType minorType,
-                              String currentType,
-                              FieldVector fieldVector) throws DorisException {
+    private boolean doConvert(
+            int col,
+            int rowIndex,
+            Types.MinorType minorType,
+            String currentType,
+            FieldVector fieldVector)
+            throws DorisException {
         switch (currentType) {
             case "NULL_TYPE":
                 break;
             case "BOOLEAN":
-                if (!minorType.equals(Types.MinorType.BIT)) return false;
+                if (!minorType.equals(Types.MinorType.BIT)) {
+                    return false;
+                }
                 BitVector bitVector = (BitVector) fieldVector;
-                Object fieldValue = bitVector.isNull(rowIndex) ? null : bitVector.get(rowIndex) != 0;
+                Object fieldValue =
+                        bitVector.isNull(rowIndex) ? null : bitVector.get(rowIndex) != 0;
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "TINYINT":
-                if (!minorType.equals(Types.MinorType.TINYINT)) return false;
+                if (!minorType.equals(Types.MinorType.TINYINT)) {
+                    return false;
+                }
                 TinyIntVector tinyIntVector = (TinyIntVector) fieldVector;
                 fieldValue = tinyIntVector.isNull(rowIndex) ? null : tinyIntVector.get(rowIndex);
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "SMALLINT":
-                if (!minorType.equals(Types.MinorType.SMALLINT)) return false;
+                if (!minorType.equals(Types.MinorType.SMALLINT)) {
+                    return false;
+                }
                 SmallIntVector smallIntVector = (SmallIntVector) fieldVector;
                 fieldValue = smallIntVector.isNull(rowIndex) ? null : smallIntVector.get(rowIndex);
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "INT":
-                if (!minorType.equals(Types.MinorType.INT)) return false;
+                if (!minorType.equals(Types.MinorType.INT)) {
+                    return false;
+                }
                 IntVector intVector = (IntVector) fieldVector;
                 fieldValue = intVector.isNull(rowIndex) ? null : intVector.get(rowIndex);
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "BIGINT":
-                if (!minorType.equals(Types.MinorType.BIGINT)) return false;
+                if (!minorType.equals(Types.MinorType.BIGINT)) {
+                    return false;
+                }
                 BigIntVector bigIntVector = (BigIntVector) fieldVector;
                 fieldValue = bigIntVector.isNull(rowIndex) ? null : bigIntVector.get(rowIndex);
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "FLOAT":
-                if (!minorType.equals(Types.MinorType.FLOAT4)) return false;
+                if (!minorType.equals(Types.MinorType.FLOAT4)) {
+                    return false;
+                }
                 Float4Vector float4Vector = (Float4Vector) fieldVector;
                 fieldValue = float4Vector.isNull(rowIndex) ? null : float4Vector.get(rowIndex);
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "TIME":
             case "DOUBLE":
-                if (!minorType.equals(Types.MinorType.FLOAT8)) return false;
+                if (!minorType.equals(Types.MinorType.FLOAT8)) {
+                    return false;
+                }
                 Float8Vector float8Vector = (Float8Vector) fieldVector;
                 fieldValue = float8Vector.isNull(rowIndex) ? null : float8Vector.get(rowIndex);
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "BINARY":
-                if (!minorType.equals(Types.MinorType.VARBINARY)) return false;
-
+                if (!minorType.equals(Types.MinorType.VARBINARY)) {
+                    return false;
+                }
                 VarBinaryVector varBinaryVector = (VarBinaryVector) fieldVector;
-                fieldValue = varBinaryVector.isNull(rowIndex) ? null : varBinaryVector.get(rowIndex);
+                fieldValue =
+                        varBinaryVector.isNull(rowIndex) ? null : varBinaryVector.get(rowIndex);
                 addValueToRow(rowIndex, fieldValue);
                 break;
             case "DECIMAL":
@@ -238,7 +265,9 @@ public class RowBatch {
             case "DECIMAL32":
             case "DECIMAL64":
             case "DECIMAL128I":
-                if (!minorType.equals(Types.MinorType.DECIMAL)) return false;
+                if (!minorType.equals(Types.MinorType.DECIMAL)) {
+                    return false;
+                }
                 DecimalVector decimalVector = (DecimalVector) fieldVector;
                 if (decimalVector.isNull(rowIndex)) {
                     addValueToRow(rowIndex, null);
@@ -249,42 +278,73 @@ public class RowBatch {
                 break;
             case "DATE":
             case "DATEV2":
-                if (!minorType.equals(Types.MinorType.VARCHAR)) return false;
-                VarCharVector date = (VarCharVector) fieldVector;
-                if (date.isNull(rowIndex)) {
-                    addValueToRow(rowIndex, null);
-                    break;
+                if (!minorType.equals(Types.MinorType.DATEDAY)
+                        && !minorType.equals(Types.MinorType.VARCHAR)) {
+                    return false;
+                }
+                if (minorType.equals(Types.MinorType.VARCHAR)) {
+                    VarCharVector date = (VarCharVector) fieldVector;
+                    if (date.isNull(rowIndex)) {
+                        addValueToRow(rowIndex, null);
+                        break;
+                    }
+                    String stringValue = new String(date.get(rowIndex));
+                    LocalDate localDate = LocalDate.parse(stringValue, dateFormatter);
+                    addValueToRow(rowIndex, localDate);
+                } else {
+                    DateDayVector date = (DateDayVector) fieldVector;
+                    if (date.isNull(rowIndex)) {
+                        addValueToRow(rowIndex, null);
+                        break;
+                    }
+                    LocalDate localDate = LocalDate.ofEpochDay(date.get(rowIndex));
+                    addValueToRow(rowIndex, localDate);
                 }
-                String stringValue = new String(date.get(rowIndex));
-                LocalDate localDate = LocalDate.parse(stringValue, dateFormatter);
-                addValueToRow(rowIndex, localDate);
                 break;
             case "DATETIME":
-                if (!minorType.equals(Types.MinorType.VARCHAR)) return false;
-                VarCharVector timeStampSecVector = (VarCharVector) fieldVector;
-                if (timeStampSecVector.isNull(rowIndex)) {
-                    addValueToRow(rowIndex, null);
-                    break;
+                if (!minorType.equals(Types.MinorType.TIMESTAMPMICRO)
+                        && !minorType.equals(Types.MinorType.VARCHAR)) {
+                    return false;
+                }
+                if (minorType.equals(Types.MinorType.VARCHAR)) {
+                    VarCharVector varCharVector = (VarCharVector) fieldVector;
+                    if (varCharVector.isNull(rowIndex)) {
+                        addValueToRow(rowIndex, null);
+                        break;
+                    }
+                    String stringValue = new String(varCharVector.get(rowIndex));
+                    LocalDateTime parse = LocalDateTime.parse(stringValue, dateTimeFormatter);
+                    addValueToRow(rowIndex, parse);
+                } else {
+                    LocalDateTime dateTime = getDateTime(rowIndex, fieldVector);
+                    addValueToRow(rowIndex, dateTime);
                 }
-                stringValue = new String(timeStampSecVector.get(rowIndex));
-                LocalDateTime parse = LocalDateTime.parse(stringValue, dateTimeFormatter);
-                addValueToRow(rowIndex, parse);
                 break;
             case "DATETIMEV2":
-                if (!minorType.equals(Types.MinorType.VARCHAR)) return false;
-                VarCharVector timeStampV2SecVector = (VarCharVector) fieldVector;
-                if (timeStampV2SecVector.isNull(rowIndex)) {
-                    addValueToRow(rowIndex, null);
-                    break;
+                if (!minorType.equals(Types.MinorType.TIMESTAMPMICRO)
+                        && !minorType.equals(Types.MinorType.VARCHAR)) {
+                    return false;
+                }
+                if (minorType.equals(Types.MinorType.VARCHAR)) {
+                    VarCharVector varCharVector = (VarCharVector) fieldVector;
+                    if (varCharVector.isNull(rowIndex)) {
+                        addValueToRow(rowIndex, null);
+                        break;
+                    }
+                    String stringValue = new String(varCharVector.get(rowIndex));
+                    stringValue = completeMilliseconds(stringValue);
+                    LocalDateTime parse = LocalDateTime.parse(stringValue, dateTimeV2Formatter);
+                    addValueToRow(rowIndex, parse);
+                } else {
+                    LocalDateTime dateTime = getDateTime(rowIndex, fieldVector);
+                    addValueToRow(rowIndex, dateTime);
                 }
-                stringValue = new String(timeStampV2SecVector.get(rowIndex));
-                stringValue = completeMilliseconds(stringValue);
-                parse = LocalDateTime.parse(stringValue, dateTimeV2Formatter);
-                addValueToRow(rowIndex, parse);
                 break;
             case "LARGEINT":
-                if (!minorType.equals(Types.MinorType.FIXEDSIZEBINARY) &&
-                        !minorType.equals(Types.MinorType.VARCHAR)) return false;
+                if (!minorType.equals(Types.MinorType.FIXEDSIZEBINARY)
+                        && !minorType.equals(Types.MinorType.VARCHAR)) {
+                    return false;
+                }
                 if (minorType.equals(Types.MinorType.FIXEDSIZEBINARY)) {
                     FixedSizeBinaryVector largeIntVector = (FixedSizeBinaryVector) fieldVector;
                     if (largeIntVector.isNull(rowIndex)) {
@@ -309,7 +369,7 @@ public class RowBatch {
                         addValueToRow(rowIndex, null);
                         break;
                     }
-                    stringValue = new String(largeIntVector.get(rowIndex));
+                    String stringValue = new String(largeIntVector.get(rowIndex));
                     BigInteger largeInt = new BigInteger(stringValue);
                     addValueToRow(rowIndex, largeInt);
                     break;
@@ -318,24 +378,31 @@ public class RowBatch {
             case "VARCHAR":
             case "STRING":
             case "JSONB":
-                if (!minorType.equals(Types.MinorType.VARCHAR)) return false;
+                if (!minorType.equals(Types.MinorType.VARCHAR)) {
+                    return false;
+                }
                 VarCharVector varCharVector = (VarCharVector) fieldVector;
                 if (varCharVector.isNull(rowIndex)) {
                     addValueToRow(rowIndex, null);
                     break;
                 }
-                stringValue = new String(varCharVector.get(rowIndex));
+                String stringValue = new String(varCharVector.get(rowIndex));
                 addValueToRow(rowIndex, stringValue);
                 break;
             case "ARRAY":
-                if (!minorType.equals(Types.MinorType.LIST)) return false;
+                if (!minorType.equals(Types.MinorType.LIST)) {
+                    return false;
+                }
                 ListVector listVector = (ListVector) fieldVector;
-                Object listValue = listVector.isNull(rowIndex) ? null : listVector.getObject(rowIndex);
-                //todo: when the subtype of array is date, conversion is required
+                Object listValue =
+                        listVector.isNull(rowIndex) ? null : listVector.getObject(rowIndex);
+                // todo: when the subtype of array is date, conversion is required
                 addValueToRow(rowIndex, listValue);
                 break;
             case "MAP":
-                if (!minorType.equals(Types.MinorType.MAP)) return false;
+                if (!minorType.equals(Types.MinorType.MAP)) {
+                    return false;
+                }
                 MapVector mapVector = (MapVector) fieldVector;
                 UnionMapReader reader = mapVector.getReader();
                 if (mapVector.isNull(rowIndex)) {
@@ -350,7 +417,9 @@ public class RowBatch {
                 addValueToRow(rowIndex, mapValue);
                 break;
             case "STRUCT":
-                if (!minorType.equals(Types.MinorType.STRUCT)) return false;
+                if (!minorType.equals(Types.MinorType.STRUCT)) {
+                    return false;
+                }
                 StructVector structVector = (StructVector) fieldVector;
                 if (structVector.isNull(rowIndex)) {
                     addValueToRow(rowIndex, null);
@@ -367,15 +436,33 @@ public class RowBatch {
         return true;
     }
 
+    private LocalDateTime getDateTime(int rowIndex, FieldVector fieldVector) {
+        TimeStampMicroVector vector = (TimeStampMicroVector) fieldVector;
+        if (vector.isNull(rowIndex)) {
+            return null;
+        }
+        long time = vector.get(rowIndex);
+        Instant instant;
+        if (time / 10000000000L == 0) { // datetime(0)
+            instant = Instant.ofEpochSecond(time);
+        } else if (time / 10000000000000L == 0) { // datetime(3)
+            instant = Instant.ofEpochMilli(time);
+        } else { // datetime(6)
+            instant = Instant.ofEpochSecond(time / 1000000, time % 1000000 * 1000);
+        }
+        LocalDateTime dateTime = LocalDateTime.ofInstant(instant, ZoneId.systemDefault());
+        return dateTime;
+    }
+
     private String completeMilliseconds(String stringValue) {
-        if(stringValue.length() == DATETIMEV2_PATTERN.length()){
+        if (stringValue.length() == DATETIMEV2_PATTERN.length()) {
             return stringValue;
         }
         StringBuilder sb = new StringBuilder(stringValue);
-        if(stringValue.length() == DATETIME_PATTERN.length()){
+        if (stringValue.length() == DATETIME_PATTERN.length()) {
             sb.append(".");
         }
-        while (sb.toString().length() < DATETIMEV2_PATTERN.length()){
+        while (sb.toString().length() < DATETIMEV2_PATTERN.length()) {
             sb.append(0);
         }
         return sb.toString();
@@ -383,7 +470,8 @@ public class RowBatch {
 
     public List<Object> next() {
         if (!hasNext()) {
-            String errMsg = "Get row offset:" + offsetInRowBatch + " larger than row size: " + readRowCount;
+            String errMsg =
+                    "Get row offset:" + offsetInRowBatch + " larger than row size: " + readRowCount;
             logger.error(errMsg);
             throw new NoSuchElementException(errMsg);
         }
