@@ -19,8 +19,7 @@ package org.apache.doris.flink.sink.writer;
 
 import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.api.connector.sink2.Sink;
-import org.apache.flink.api.connector.sink2.StatefulSink;
-import org.apache.flink.api.connector.sink2.TwoPhaseCommittingSink;
+import org.apache.flink.metrics.groups.SinkWriterMetricGroup;
 import org.apache.flink.runtime.checkpoint.CheckpointIDCounter;
 import org.apache.flink.util.concurrent.ExecutorThreadFactory;
 
@@ -60,8 +59,7 @@ import static org.apache.doris.flink.sink.LoadStatus.SUCCESS;
  * @param <IN>
  */
 public class DorisWriter<IN>
-        implements StatefulSink.StatefulSinkWriter<IN, DorisWriterState>,
-                TwoPhaseCommittingSink.PrecommittingSinkWriter<IN, DorisCommittable> {
+        implements DorisAbstractWriter<IN, DorisWriterState, DorisCommittable> {
     private static final Logger LOG = LoggerFactory.getLogger(DorisWriter.class);
     private static final List<String> DORIS_SUCCESS_STATUS =
             new ArrayList<>(Arrays.asList(SUCCESS, PUBLISH_TIMEOUT));
@@ -82,6 +80,8 @@ public class DorisWriter<IN>
     private transient Thread executorThread;
     private transient volatile Exception loadException = null;
     private BackendUtil backendUtil;
+    private SinkWriterMetricGroup sinkMetricGroup;
+    private Map<String, DorisWriteMetrics> sinkMetricsMap = new ConcurrentHashMap<>();
 
     public DorisWriter(
             Sink.InitContext initContext,
@@ -96,7 +96,7 @@ public class DorisWriter<IN>
                         .orElse(CheckpointIDCounter.INITIAL_CHECKPOINT_ID - 1);
         this.curCheckpointId = lastCheckpointId + 1;
         LOG.info("restore checkpointId {}", lastCheckpointId);
-        LOG.info("labelPrefix " + executionOptions.getLabelPrefix());
+        LOG.info("labelPrefix {}", executionOptions.getLabelPrefix());
         this.labelPrefix = executionOptions.getLabelPrefix();
         this.subtaskId = initContext.getSubtaskId();
         this.scheduledExecutorService =
@@ -107,7 +107,7 @@ public class DorisWriter<IN>
         this.executionOptions = executionOptions;
         this.intervalTime = executionOptions.checkInterval();
         this.globalLoading = false;
-
+        sinkMetricGroup = initContext.metricGroup();
         initializeLoad(state);
         serializer.initial();
     }
@@ -166,7 +166,7 @@ public class DorisWriter<IN>
     }
 
     @Override
-    public void write(IN in, Context context) throws IOException {
+    public void write(IN in, Context context) throws IOException, InterruptedException {
         checkLoadException();
         writeOneDorisRecord(serializer.serialize(in));
     }
@@ -176,7 +176,7 @@ public class DorisWriter<IN>
         writeOneDorisRecord(serializer.flush());
     }
 
-    public void writeOneDorisRecord(DorisRecord record) throws IOException {
+    public void writeOneDorisRecord(DorisRecord record) throws IOException, InterruptedException {
 
         if (record == null || record.getRow() == null) {
             // ddl or value is null
@@ -197,10 +197,24 @@ public class DorisWriter<IN>
             streamLoader.startLoad(currentLabel, false);
             loadingMap.put(tableKey, true);
             globalLoading = true;
+            registerMetrics(tableKey);
         }
         streamLoader.writeRecord(record.getRow());
     }
 
+    @VisibleForTesting
+    public void setSinkMetricGroup(SinkWriterMetricGroup sinkMetricGroup) {
+        this.sinkMetricGroup = sinkMetricGroup;
+    }
+
+    public void registerMetrics(String tableKey) {
+        if (sinkMetricsMap.containsKey(tableKey)) {
+            return;
+        }
+        DorisWriteMetrics metrics = DorisWriteMetrics.of(sinkMetricGroup, tableKey);
+        sinkMetricsMap.put(tableKey, metrics);
+    }
+
     @Override
     public Collection<DorisCommittable> prepareCommit() throws IOException, InterruptedException {
         // Verify whether data is written during a checkpoint
@@ -219,13 +233,16 @@ public class DorisWriter<IN>
                 continue;
             }
             DorisStreamLoad dorisStreamLoad = streamLoader.getValue();
-            LabelGenerator labelGenerator = getLabelGenerator(tableIdentifier);
-            String currentLabel = labelGenerator.generateTableLabel(curCheckpointId);
-            RespContent respContent = dorisStreamLoad.stopLoad(currentLabel);
+            RespContent respContent = dorisStreamLoad.stopLoad();
+            // refresh metrics
+            if (sinkMetricsMap.containsKey(tableIdentifier)) {
+                DorisWriteMetrics dorisWriteMetrics = sinkMetricsMap.get(tableIdentifier);
+                dorisWriteMetrics.flush(respContent);
+            }
             if (!DORIS_SUCCESS_STATUS.contains(respContent.getStatus())) {
                 String errMsg =
                         String.format(
-                                "tabel {} stream load error: %s, see more in %s",
+                                "table %s stream load error: %s, see more in %s",
                                 tableIdentifier,
                                 respContent.getMessage(),
                                 respContent.getErrorURL());
@@ -363,6 +380,11 @@ public class DorisWriter<IN>
         this.dorisStreamLoadMap = streamLoadMap;
     }
 
+    @VisibleForTesting
+    public void setDorisMetricsMap(Map<String, DorisWriteMetrics> metricsMap) {
+        this.sinkMetricsMap = metricsMap;
+    }
+
     @Override
     public void close() throws Exception {
         LOG.info("Close DorisWriter.");
