@@ -17,11 +17,20 @@
 
 package org.apache.doris.flink.tools.cdc.mysql;
 
+import org.apache.flink.table.types.logical.TimestampType;
 import org.apache.flink.util.Preconditions;
 
 import org.apache.doris.flink.catalog.doris.DorisType;
 
+import static org.apache.doris.flink.catalog.DorisTypeMapper.MAX_SUPPORTED_DATE_TIME_PRECISION;
+
 public class MysqlType {
+
+    // MySQL driver returns width of timestamp types instead of precision.
+    // 19 characters are used for zero-precision timestamps while others
+    // require 19 + precision + 1 characters with the additional character
+    // required for the decimal separator.
+    private static final int ZERO_PRECISION_TIMESTAMP_COLUMN_SIZE = 19;
     private static final String BIT = "BIT";
     private static final String BOOLEAN = "BOOLEAN";
     private static final String BOOL = "BOOL";
@@ -82,6 +91,7 @@ public class MysqlType {
     private static final String LONGBLOB = "LONGBLOB";
     private static final String JSON = "JSON";
     private static final String ENUM = "ENUM";
+    private static final String SET = "SET";
 
     public static String toDorisType(String type, Integer length, Integer scale) {
         switch (type.toUpperCase()) {
@@ -144,8 +154,35 @@ public class MysqlType {
                 return DorisType.DATE_V2;
             case DATETIME:
             case TIMESTAMP:
-                return String.format(
-                        "%s(%s)", DorisType.DATETIME_V2, Math.min(length == null ? 0 : length, 6));
+                // default precision is 0
+                // see https://dev.mysql.com/doc/refman/8.0/en/date-and-time-type-syntax.html
+                if (length == null
+                        || length <= 0
+                        || length == ZERO_PRECISION_TIMESTAMP_COLUMN_SIZE) {
+                    return String.format("%s(%s)", DorisType.DATETIME_V2, 0);
+                } else if (length > ZERO_PRECISION_TIMESTAMP_COLUMN_SIZE + 1) {
+                    // Timestamp with a fraction of seconds.
+                    // For example, 2024-01-01 01:01:01.1
+                    // The decimal point will occupy 1 character.
+                    // Thus,the length of the timestamp is 21.
+                    return String.format(
+                            "%s(%s)",
+                            DorisType.DATETIME_V2,
+                            Math.min(
+                                    length - ZERO_PRECISION_TIMESTAMP_COLUMN_SIZE - 1,
+                                    MAX_SUPPORTED_DATE_TIME_PRECISION));
+                } else if (length <= TimestampType.MAX_PRECISION) {
+                    // For Debezium JSON data, the timestamp/datetime length ranges from 0 to 9.
+                    return String.format(
+                            "%s(%s)",
+                            DorisType.DATETIME_V2,
+                            Math.min(length, MAX_SUPPORTED_DATE_TIME_PRECISION));
+                } else {
+                    throw new UnsupportedOperationException(
+                            "Unsupported length: "
+                                    + length
+                                    + " for MySQL TIMESTAMP/DATETIME types");
+                }
             case CHAR:
             case VARCHAR:
                 Preconditions.checkNotNull(length);
@@ -164,6 +201,7 @@ public class MysqlType {
             case LONGBLOB:
             case BINARY:
             case VARBINARY:
+            case SET:
                 return DorisType.STRING;
             case JSON:
                 return DorisType.JSONB;
